pytilities.delegation

Package pytilities :: Package delegation |
[hide private]
[frames] | no frames]

# Package delegation

source code

Delegation utilities

Classes:

> Delegator
>   An AttributeCollection that delegates attributes
> DelegatorFactory
>   Allows easy creation of delegators with profiles
> Profile
>   A delegation profile, states what to delegate

Decorators:

> delegator_factory
>   Installs a DelegatorFactory on an AttributeCollectionBase
> delegated
>   Includes the decorated attribute in the specified delegation profile

Submodules | [hide private]
pytilities.delegation.decorators: Various decorators to ease delegation pytilities.delegation.delegator pytilities.delegation.delegatorfactory pytilities.delegation.profile

Variables | [hide private]
| __package__ = ``'``pytilities.delegation``'``